@@ -854,7 +854,7 @@ class Message(ABC):
         :param http_code:
         :return:
         """
-        assert self.status_code == http_code, f'[校验失败,http_code 实际值:{self.status_code} == 预期值:{http_code}]'
+        assert self.status_code == http_code, f'[校验失败,http_code 实际值:{self.status_code} != 预期值:{http_code}]'
         logger.info(f'[校验成功,http_code 实际值:{self.status_code} == 预期值:{http_code}]')
         return self
     
@@ -865,7 +865,7 @@ class Message(ABC):
         :param code: response code number
         :return:
         """
-        assert self.code == code, f'[校验失败,response.code 实际值:{self.code} == 预期值:{code}]'
+        assert self.code == code, f'[校验失败,response.code 实际值:{self.code} != 预期值:{code}]'
         logger.info(f'[校验成功,response.code 实际值:{self.code} == 预期值:{code}]')
         return self
     
@@ -876,7 +876,7 @@ class Message(ABC):
         @actual_val : 实际值,取自response data
         @desc : 描述校验信息
         """
-        assert actual_val == expect_val, f'[校验失败,{desc} 实际值:{actual_val} == 预期值:{expect_val}]'
+        assert actual_val == expect_val, f'[校验失败,{desc} 实际值:{actual_val} != 预期值:{expect_val}]'
         logger.info(f'[校验成功,{desc} 实际值:{actual_val} == 预期值:{expect_val}]')
         return self
 
@@ -1057,7 +1057,7 @@ class ServiceStub(ABC):
         if not session.expand_kwargs:
             session.expand_kwargs = kwargs
     
-    def _do_twirp_rpc(self, api, request: Message = Message, response: Message = Message):
+    def _do_twirp_rpc(self, api, request: Message, response: Message):
         api = api + self.suffix_url
         url = self._target + "/twirp" + api
         logger.info(f'[请求URL]:{url}')
@@ -1071,13 +1071,14 @@ class ServiceStub(ABC):
             timeout=60 * 5,
             cookies=self.kwargs.get("cookies")
         )
+        # TODO 优化URL获取通过r.request.url,但也不一定是对的
         logger.info(f'[请求cookies]:{r.request.headers._store.get("cookie")}')
         logger.info(f'[请求headers]:{r.request.headers}')
         
         logger.info(f'[响应结果]:{r.json()}')
         logger.info(f'[响应http_code]:{r.status_code}')
         logger.info(f'[响应耗时]:{r.elapsed.total_seconds()}秒')
-        logger.info(f'[X-Trace-Id]:{r.request.headers.get("X-Trace-Id")}')
+        logger.info(f'[X-Trace-Id]:{r.headers.get("X-Trace-Id")}')
         # logger.info(f'[响应cookies]:{r.cookies}')
         response.__dict__.update(r.__dict__)
         response.from_json(r.content)
